Public Function Reference
=========================

.. autosummary::
   :toctree: generated


Surface Calculation
-------------------

.. autofunction:: surf.load_tsdata

.. autofunction:: surf.find_omega_surfs

Grid Interpretation
-------------------

.. autofunction:: grid.build_nemo_hgrid

.. autofunction:: grid.load_hgriddata

.. autofunction:: grid.load_zgriddata

Equation of State
-------------------

.. autofunction:: eos.NEMO_eos

.. autofunction:: eos.calc_seos

.. autofunction:: eos.calc_seos_s_t

.. autofunction:: eos.calc_eos

.. autofunction:: eos.calc_eos_s_t

